Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(338)

Unified Diff: pkg/analyzer/lib/src/generated/element.dart

Issue 1008433002: Task: Build Directive Elements. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 5 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | pkg/analyzer/lib/src/generated/resolver.dart » ('j') | pkg/analyzer/lib/src/task/dart.dart » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/lib/src/generated/element.dart
diff --git a/pkg/analyzer/lib/src/generated/element.dart b/pkg/analyzer/lib/src/generated/element.dart
index d8061b90a054ab5e96ce73cdaaefb9ac303ab608..af8e753456545e50b267f7914462af5c4ceee882 100644
--- a/pkg/analyzer/lib/src/generated/element.dart
+++ b/pkg/analyzer/lib/src/generated/element.dart
@@ -3632,9 +3632,9 @@ class ExportElementImpl extends UriReferencedElementImpl
List<NamespaceCombinator> combinators = NamespaceCombinator.EMPTY_ARRAY;
/**
* Initialize a newly created export element.
*/
- ExportElementImpl() : super(null, -1);
+ ExportElementImpl(int offset) : super(null, offset);
@override
String get identifier => exportedLibrary.name;
@@ -5438,8 +5438,8 @@ class ImportElementImpl extends UriReferencedElementImpl
PrefixElement prefix;
/**
- * Initialize a newly created import element at the given [offset]. The offset
- * may be `-1` if the import is synthetic.
+ * Initialize a newly created import element at the given [offset].
+ * The offset may be `-1` if the import is synthetic.
*/
ImportElementImpl(int offset) : super(null, offset);
« no previous file with comments | « no previous file | pkg/analyzer/lib/src/generated/resolver.dart » ('j') | pkg/analyzer/lib/src/task/dart.dart » ('J')
@@ -3632,9 +3632,9 @@ class ExportElementImpl extends UriReferencedElementImpl
List<NamespaceCombinator> combinators = NamespaceCombinator.EMPTY_ARRAY;
/**
- * Initialize a newly created export element.
+ * Initialize a newly created export element at the given [offset].
*/

Powered by Google App Engine
This is Rietveld 408576698